@@ -1228,6 +1228,19 @@ void DStyle::drawControl(const QStyle *style, DStyle::ControlElement ce, const Q
                 dstyle.drawPrimitive(PE_IconButtonIcon, &new_opt, p, w);
             }
 
+            // 有新信息时添加小红点
+            if (w && w->property("_d_dtk_newNotification").toBool()){
+                DPalette pa = DGuiApplicationHelper::instance()->standardPalette(DGuiApplicationHelper::LightType);
+                // 按图标大小50x50时，小红点大小6x6，距离右边和上面8个像素的比例绘制
+                const int redPointRadius = 3;
+                int redPointPadding = (8 * w->size().width() / 50) + redPointRadius;
+                p->setPen(pa.color(DPalette::TextWarning));
+                p->setBrush(pa.color(DPalette::TextWarning));
+                p->setRenderHint(QPainter::Antialiasing);
+                p->drawEllipse(QPointF(w->size().width()-redPointPadding, redPointPadding),
+                               redPointRadius, redPointRadius);
+            }
+
             if (btn->state & State_HasFocus) {
                 if (btn->features & DStyleOptionButton::FloatingButton) {
                     int border_width = dstyle.pixelMetric(PM_FocusBorderWidth, opt, w);
@@ -1726,6 +1739,8 @@ case SP_##Value: { \
         return QIcon::fromTheme("password_hide");
     case SP_IndicatorSearch:
         return QIcon::fromTheme("search_indicator");
+    case SP_TitleMoreButton:
+        return QIcon::fromTheme("titlebar_more");
     default:
         break;
     }
@@ -1776,7 +1791,7 @@ int DStyle::styleHint(QStyle::StyleHint sh, const QStyleOption *opt, const QWidg
     case SH_ToolTipLabel_Opacity:
         return 255;
     case SH_RequestSoftwareInputPanel:
-        return RSIP_OnMouseClickAndAlreadyFocused;
+        return RSIP_OnMouseClick;
     case SH_ItemView_ScrollMode:
         return QAbstractItemView::ScrollPerPixel;
     case SH_Widget_Animation_Duration:
